%define anolis_release 1

%global usrgrp_name saslauth
%global plugindir %{_libdir}/sasl2

Name:           cyrus-sasl
Version:        2.1.28
Release:        %{anolis_release}%{?dist}
Summary:        Implementation of Cyrus SASL API

License:        BSD with advertising
URL:            https://www.cyrusimap.org/sasl/
Source0:        https://github.com/cyrusimap/cyrus-sasl/releases/download/cyrus-sasl-%{version}/cyrus-sasl-%{version}.tar.gz
Source1:        saslauthd.service
Source2:        saslauthd.sysconfig

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  groff
BuildRequires:  gdbm-devel
BuildRequires:  krb5-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  mysql-devel
BuildRequires:  libpq-devel
BuildRequires:  zlib-devel
BuildRequires:  openldap-devel
BuildRequires:  libdb-devel
BuildRequires:  python3
BuildRequires:  nss_wrapper
BuildRequires:  socket_wrapper
BuildRequires:  krb5-server
BuildRequires:  make
Requires(pre):  /usr/sbin/useradd /usr/sbin/groupadd
Requires(postun): /usr/sbin/userdel /usr/sbin/groupdel
Requires:       /sbin/nologin
Requires:       systemd
Requires:       user(%{usrgrp_name})
Requires:       group(%{usrgrp_name})

%description
This is the Cyrus SASL API implementation. It can be used on the client
or server side to provide authentication and authorization services.
See RFC 4422 for more information.

%package lib
Summary: Shared libraries needed by applications which use Cyrus SASL

%description lib
The %{name}-lib package contains shared libraries needed by applications
using the Cyrus SASL library.

%package devel
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: pkgconfig
Summary: Files needed for developing applications with Cyrus SASL

%description devel
The %{name}-devel package contains files needed for developing and
compiling applications which use the Cyrus SASL library.

%package gssapi
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: GSSAPI authentication support for Cyrus SASL

%description gssapi
The %{name}-gssapi package contains the Cyrus SASL plugins which
support GSSAPI authentication. GSSAPI is commonly used for Kerberos
authentication.

%package plain
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: PLAIN and LOGIN authentication support for Cyrus SASL

%description plain
The %{name}-plain package contains the Cyrus SASL plugins which support
PLAIN and LOGIN authentication schemes.

%package md5
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: CRAM-MD5 and DIGEST-MD5 authentication support for Cyrus SASL

%description md5
The %{name}-md5 package contains the Cyrus SASL plugins which support
CRAM-MD5 and DIGEST-MD5 authentication schemes.

%package ntlm
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: NTLM authentication support for Cyrus SASL

%description ntlm
The %{name}-ntlm package contains the Cyrus SASL plugin which supports
the NTLM authentication scheme.

%package scram
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: SCRAM auxprop support for Cyrus SASL
%description scram
The %{name}-scram package contains the Cyrus SASL plugin which supports
the SCRAM authentication scheme.

%package gs2
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: GS2 support for Cyrus SASL

%description gs2
The %{name}-gs2 package contains the Cyrus SASL plugin which supports
the GS2 authentication scheme.

%package sql
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: SQL auxprop support for Cyrus SASL

%description sql
The %{name}-sql package contains the Cyrus SASL plugin which supports
using a RDBMS for storing shared secrets.

%package ldap
Requires: %{name}-lib%{?_isa} = %{version}-%{release}
Summary: LDAP auxprop support for Cyrus SASL

%description ldap
The %{name}-ldap package contains the Cyrus SASL plugin which supports using
a directory server, accessed using LDAP, for storing shared secrets.

%prep
%autosetup

# dlcompat may cause potential legal risks
find %{_builddir}/%{name}-%{version} -maxdepth 1 -name 'dlcompat-*' -exec rm -rf {} \;

%build

APPEND_CFLAGS=""
INC_DIR="$( mysql_config --include )"
if [ "x$INC_DIR" != "x-I%{_includedir}" ] ; then
        APPEND_CFLAGS="$APPEND_CFLAGS $INC_DIR"
fi 

CFLAGS="$CFLAGS $APPEND_CFLAGS"

autoreconf -f
%configure --with-pic \
        --disable-static \
        --enable-shared \
        --disable-java \
        --with-plugindir=%{plugindir} \
        --with-configdir=%{plugindir}:%{_sysconfdir}/sasl2 \
        --disable-krb4 \
        --enable-gassapi \
        --with-gss_impl=mit \
        --with-rc4 \
        --with-dbpath=/etc/sasl2/sasldb2 \
        --with-saslauthd=/run/saslauthd \
        --without-pwcheck \
        --with-ldap \
        --with-devrandom=/dev/urandom \
        --enable-anon \
        --enable-cram \
        --enable-digest \
        --enable-ntlm \
        --enable-plain \
        --enable-login \
        --enable-alwaystrue \
        --enable-httpform \
        --disable-otp \
        --enable-ldapdb \
        --enable-sql --with-mysql --with-pgsql --without-sqlite
%{make_build}
%{make_build} -C saslauthd testsaslauthd
%{make_build} -C sample
        
%install
%{make_install}
%{make_install} -C plugins
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sysconfdir}/sasl2
./libtool --mode=install \
install -m 755 sample/client %{buildroot}%{_bindir}/sasl2-sample-client
./libtool --mode=install \
install -m 755 sample/server %{buildroot}%{_bindir}/sasl2-sample-server
./libtool --mode=install \
install -m 755 saslauthd/testsaslauthd %{buildroot}%{_sbindir}/testsaslauthd

install -m 644 %{SOURCE1} -D %{buildroot}%{_unitdir}/saslauthd.service
install -m 644 %{SOURCE2} -D %{buildroot}%{_sysconfdir}/sysconfig/saslauthd

rm -f %{buildroot}%{_mandir}/cat?/*
rm -f %{buildroot}%{_libdir}/sasl2/libotp.*
find %{buildroot} -type f \( -name '*.la' -o -name '*.a' \) -delete -print

%check
make check %{?_smp_mflags}

%pre
getent group %{usrgrp_name} >/dev/null || groupadd -g 76 -r %{usrgrp_name}
getent passwd %{usrgrp_name} >/dev/null || \
        useradd -r -g %{usrgrp_name} -d /run/saslauthd \
        -s /sbin/nologin -c "Saslauthd User" %{usrgrp_name}

%post
%systemd_post saslauthd.service

%preun
%systemd_preun saslauthd.service

%postun
%systemd_postun_with_restart saslauthd.service

%files
%doc saslauthd/LDAP_SASLAUTHD
%{_mandir}/man8/*
%{_sbindir}/pluginviewer
%{_sbindir}/saslauthd
%{_sbindir}/testsaslauthd
%config(noreplace) /etc/sysconfig/saslauthd
%{_unitdir}/saslauthd.service
%ghost /run/saslauthd

%files lib
%license COPYING
%doc AUTHORS doc/html/*.html
%{_libdir}/libsasl*.so.*
%dir %{_sysconfdir}/sasl2
%{plugindir}/*anonymous*.so*
%{plugindir}/*sasldb*.so*
%{_sbindir}/saslpasswd2
%{_sbindir}/sasldblistusers2

%files devel
%{_bindir}/sasl2-sample-client
%{_bindir}/sasl2-sample-server
%{_includedir}/*
%{_libdir}/libsasl*.*so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

%files plain
%{plugindir}/*plain*.so*
%{plugindir}/*login*.so*

%files ldap
%{plugindir}/*ldapdb*.so*

%files md5
%{plugindir}/*crammd5*.so*
%{plugindir}/*digestmd5*.so*

%files ntlm
%{plugindir}/*ntlm*.so*

%files sql
%{plugindir}/*sql*.so*

%files gssapi
%{plugindir}/*gssapi*.so*

%files scram
%{plugindir}/libscram.so*

%files gs2
%{plugindir}/libgs2.so*

%changelog
* Fri Mar 11 2022 Su Lifan <su-lifan@linux.alibaba.com> - 2.1.28-1
- Initial packaging for Anolis OS 23
